@@ -74,6 +74,7 @@ new LambdaToElasticSearchAndKibana(scope: Construct, id: string, props: LambdaTo
 |userPoolClient|[`cognito.UserPoolClient`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cognito.UserPoolClient.html)|Returns an instance of cognito.UserPoolClient created by the construct|
 |identityPool|[`cognito.CfnIdentityPool`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cognito.CfnIdentityPool.html)|Returns an instance of cognito.CfnIdentityPool created by the construct|
 |elasticsearchDomain|[`elasticsearch.CfnDomain`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-elasticsearch.CfnDomain.html)|Returns an instance of elasticsearch.CfnDomain created by the construct|
+|elasticsearchDomain|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of iam.Role created by the construct for elasticsearch.CfnDomain|
 |cloudwatchAlarms|[`cloudwatch.Alarm[]`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudwatch.Alarm.html)|Returns a list of cloudwatch.Alarm created by the construct|
 
 ## Default settings
@@ -122,6 +123,7 @@ from ._jsii import *
 import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_cognito
 import aws_cdk.aws_elasticsearch
+import aws_cdk.aws_iam
 import aws_cdk.aws_lambda
 import aws_cdk.core
 
@@ -177,6 +179,11 @@ class LambdaToElasticSearchAndKibana(
     def elasticsearch_domain(self) -> aws_cdk.aws_elasticsearch.CfnDomain:
         return jsii.get(self, "elasticsearchDomain")
 
+    @builtins.property
+    @jsii.member(jsii_name="elasticsearchRole")
+    def elasticsearch_role(self) -> aws_cdk.aws_iam.Role:
+        return jsii.get(self, "elasticsearchRole")
+
     @builtins.property
     @jsii.member(jsii_name="identityPool")
     def identity_pool(self) -> aws_cdk.aws_cognito.CfnIdentityPool:
